@@ -2,9 +2,11 @@
 ## Number of distinct subsequences in a sequence
 ## =============================================
 
-nsubs <- function (x, nbstat, statlist) {
+nsubs <- function (x, nbstat, statlist, void) {
 		l <- vector(mode="integer", nbstat)
-		slength <- sum(!is.na(x))
+		x <- x[x!=void]
+		slength <- length(x)
+
 		N <- vector(mode="integer",(slength+1))
 		N[1] <- 1
 
@@ -21,19 +23,20 @@ nsubs <- function (x, nbstat, statlist) {
 
 seqsubsn <- function(seqdata, DSS=TRUE) {
 
-	if (!inherits(seqdata,"stslist")) {
+	if (!inherits(seqdata,"stslist"))
 		stop("data is not a sequence object, see seqdef function to create one")
-	}
 
 	nbseq <- seqdim(seqdata)[1]
 
-	if (DSS==TRUE) seqdata <-  suppressMessages(seqdss(seqdata))
+	if (DSS==TRUE) seqdata <- suppressMessages(seqdss(seqdata))
 
 	## alphabet
 	sl <- attr(seqdata,"alphabet")
 	ns <- length(sl)
+
+	void <- attr(seqdata,"void")
 		
-	result <- apply(seqdata,1,nsubs,nbstat=ns,statlist=sl)
+	result <- apply(seqdata,1,nsubs,nbstat=ns,statlist=sl, void=void)
 	
 	names(result) <- NULL
 	return(result)
